/*
Alvaro Pintado
pintado@unlv.nevada.edu

Objective: This program opens up a COM port for Bluetooth communication with a LEGO NXT Brick.
The program sends direct commands in the form of byte arrays to be interpreted through the
LEGO Mindstorms NXT Communication Protocol.

Notes: 
1. When writing commands to the LEGO NXT, it is advised that you do not request a response
in order to avoid the time delay of the Bluetooth chipping switching modes from receiving 
to transmiting (30 - 60 ms).
2. 

*/

// Necessary header files and namespaces in order to use the Serial Port Class

#using <System.dll>
#include <Windows.h>
#include <string>

using namespace System;
using namespace System::IO::Ports;
using namespace System::Threading;
using namespace std;

int main() {

	//Settings for COM Port
	Int32 baudRate = 9600;
	Int32 readTimeout = 500; // time limit for attempting to write to port before exiting
	Int32 writeTimeout = 500; // time limit for attempting to read from port before exiting

	//Requests Port Number from user
	Console::Write("Enter NXT Port and press Enter: ");
	String^ portNum = Console::ReadLine();
	Console::WriteLine("Opening COM port ...");
	Console::WriteLine();

	//Creates Serial Port object named "NXT" for communication over Bluetooth
	SerialPort^ NXT = gcnew SerialPort(portNum, baudRate, Parity::None, 8, StopBits::One); //creates Serial Port object named "NXT"
	NXT->ReadTimeout = readTimeout; // sets read timeout
	NXT->WriteTimeout = writeTimeout; //sets write timeout

	// Opens port for communication with NXT Brick over Bluetooth
	NXT->Open();
	Console::WriteLine(portNum + " opened for Bluetooth communication.");
	Console::WriteLine();
	Sleep(3000);

	// Byte array for a direct command to the NXT Brick to play a tone
	// See LEGO Mindstorms NXT Communication Protocol Documentation for details
	cli::array<wchar_t, 1>^ tone = { 0x06, 0x00, 0x00, 0x03, 0x64, 0x0E, 0xF4, 0x01 };
	
	//Writes direct command to play a tone to the NXT Brick
	Console::WriteLine("Play a tone");
	Sleep(1000);
	NXT->Write(tone, 0, 8);

	//Closes the port and closes the program
	Console::WriteLine("Closing program...");
	Sleep(3000);
	NXT->Close();
	exit(0);
}      